@@ -1,9 +1,19 @@
-from typing import Type, Union
+from typing import List, Type, Union
 
 import ipywidgets as widgets
 import traitlets
 
 
+class CallableButton(widgets.Button):
+
+    def link_to_model(self, model, view, name):
+        func = getattr(model, name)
+        self.on_click(lambda _: func())
+
+        # Allow widget to be disabled if model is
+        yield widgets.dlink((view, "disabled"), (self, "disabled"))
+
+
 class ModelViewWidget(widgets.HBox):
     """Widget to render a view over a a model"""
 
@@ -36,9 +46,45 @@ class ModelViewWidget(widgets.HBox):
             )
 
         super().__init__(
-            children=[self.description_label, self.widgets_vbox,], **kwargs,
+            children=[
+                self.description_label,
+                self.widgets_vbox,
+            ],
+            **kwargs,
         )
 
+    def _create_links_to_model(self, model: traitlets.HasTraits) -> List[traitlets.link]:
+        """Create traitlet links between model and widgets
+
+        :param model:
+        :return:
+        """
+        for n, w in self.widgets.items():
+            try:
+                # Allow widget to handle linking
+                if hasattr(w, "link_to_model"):
+                    yield from w.link_to_model(model, self, n)
+                else:
+                    yield widgets.link((model, n), (w, "value"))
+
+                    # Allow widget to be disabled if model is
+                    if hasattr(w, "disabled"):
+                        yield widgets.dlink((self, "disabled"), (w, "disabled"))
+
+            except:
+                if self._logger is not None:
+                    self._logger.exception(f"Error in linking widget {n}")
+
+    @traitlets.observe("value")
+    def _update_model_links(self, change):
+        for link in self._links:
+            link.unlink()
+        self._links.clear()
+
+        model = change["new"]
+        with model.hold_trait_notifications():
+            self._links = list(self._create_links_to_model(model))
+
     @classmethod
     def specialise_for_cls(
         cls, klass: Union[Type[traitlets.HasTraits], str]
@@ -50,23 +96,3 @@ class ModelViewWidget(widgets.HBox):
         """
         klass_name = getattr(klass, "__name__", klass)
         return type(f"{klass_name}View", (cls,), {"value": traitlets.Instance(klass)})
-
-    @traitlets.observe("value")
-    def _model_changed(self, change):
-        for link in self._links:
-            link.unlink()
-        self._links.clear()
-
-        model = change["new"]
-        for n, w in self.widgets.items():
-            try:
-                self._links.append(widgets.link((model, n), (w, "value")))
-
-                # Allow widget to be disabled if model is
-                if hasattr(w, "disabled"):
-                    self._links.append(
-                        widgets.dlink((self, "disabled"), (w, "disabled"))
-                    )
-            except:
-                if self._logger is not None:
-                    self._logger.exception(f"Error in linking widget {n}")
